@@ -256,7 +256,7 @@ class ProjectPoints:
         Parameters
         ----------
         site : int | str
-            Site number of interest.
+            Site number (gid) of interest (typically the resource gid).
 
         Returns
         -------
@@ -516,6 +516,24 @@ class ProjectPoints:
 
         return self.sam_config_obj.inputs
 
+    @property
+    def all_sam_input_keys(self):
+        """Get a list of unique input keys from all SAM technology configs.
+
+        Returns
+        -------
+        all_sam_input_keys : list
+            List of unique strings where each string is a input key for the
+            SAM technology configs. For example, "gcr" or "losses" for PVWatts
+            or "wind_turbine_hub_ht" for windpower.
+        """
+        keys = []
+        for sam_config in self.sam_configs.values():
+            keys += list(sam_config.keys())
+
+        keys = list(set(keys))
+        return keys
+
     def _check_points_config_mapping(self):
         """
         Check to ensure the project points (df) and SAM configs
@@ -866,21 +884,25 @@ class ProjectPoints:
         with res_cls(res_file, **res_kwargs) as f:
             gids = f.lat_lon_gid(lat_lons)  # pylint: disable=no-member
 
-        if len(gids) != len(np.unique(gids)):
-            uniques, pos, counts = np.unique(gids, return_counts=True,
-                                             return_inverse=True)
-            duplicates = {}
-            for idx in np.where(counts > 1)[0]:
-                duplicate_lat_lons = lat_lons[np.where(pos == idx)[0]]
-                duplicates[uniques[idx]] = duplicate_lat_lons
+        if isinstance(gids, int):
+            gids = [gids]
+        else:
+            if len(gids) != len(np.unique(gids)):
+                uniques, pos, counts = np.unique(gids, return_counts=True,
+                                                 return_inverse=True)
+                duplicates = {}
+                for idx in np.where(counts > 1)[0]:
+                    duplicate_lat_lons = lat_lons[np.where(pos == idx)[0]]
+                    duplicates[uniques[idx]] = duplicate_lat_lons
 
-            msg = ('reV Cannot currently handle duplicate Resource gids! The '
-                   'given latitude and longitudes map to the same gids:\n{}'
-                   .format(duplicates))
-            logger.error(msg)
-            raise RuntimeError(msg)
+                msg = ('reV Cannot currently handle duplicate Resource gids! '
+                       'The given latitude and longitudes map to the same '
+                       'gids:\n{}'.format(duplicates))
+                logger.error(msg)
+                raise RuntimeError(msg)
+
+            gids = gids.tolist()
 
-        gids = gids.tolist()
         logger.debug('- Resource gids:\n{}'.format(gids))
 
         pp = cls(gids, sam_config, tech=tech, res_file=res_file,
