@@ -231,7 +231,7 @@ class TechMapping:
 
         n_finished = 0
         futures = {}
-        loggers = __name__
+        loggers = [__name__, 'reV']
         with SpawnProcessPool(max_workers=self._max_workers,
                               loggers=loggers) as exe:
 
